# API Reference <a name="API Reference"></a>

## Constructs <a name="Constructs"></a>

### AmplifyExportedBackend <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend"></a>

* Used to include the backend generated by running `amplify export --out <path>` into the cdk app.

> <amplify-export-docs-path>

#### Initializers <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.Initializer"></a>

```typescript
import { AmplifyExportedBackend } from '@aws-amplify/cdk-exported-backend'

new AmplifyExportedBackend(scope: Construct, id: string, props: AmplifyExportedBackendProps)
```

##### `scope`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.scope"></a>

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

The parent construct of this template.

---

##### `id`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.id"></a>

- *Type:* `string`

The ID of this construct.

---

##### `props`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.props"></a>

- *Type:* [`@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps`](#@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps)

Initialization properties.

---

#### Methods <a name="Methods"></a>

##### `apiRestNestedStack` <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.apiRestNestedStack"></a>

```typescript
public apiRestNestedStack(resourceName: string)
```

###### `resourceName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.resourceName"></a>

- *Type:* `string`

---

##### `authNestedStack` <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.authNestedStack"></a>

```typescript
public authNestedStack()
```

##### `graphqlNestedStacks` <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.graphqlNestedStacks"></a>

```typescript
public graphqlNestedStacks()
```

##### `lambdaFunctionNestedStackByName` <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.lambdaFunctionNestedStackByName"></a>

```typescript
public lambdaFunctionNestedStackByName(functionName: string)
```

###### `functionName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.functionName"></a>

- *Type:* `string`

the function name to get from the nested stack.

---

##### `lambdaFunctionNestedStacks` <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.lambdaFunctionNestedStacks"></a>

```typescript
public lambdaFunctionNestedStacks()
```

##### `nestedStackByCategortService` <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.nestedStackByCategortService"></a>

```typescript
public nestedStackByCategortService(category: string, service: string)
```

###### `category`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.category"></a>

- *Type:* `string`

---

###### `service`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.service"></a>

- *Type:* `string`

---

##### `nestedStacksByCategory` <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.nestedStacksByCategory"></a>

```typescript
public nestedStacksByCategory(category: string, resourceName?: string)
```

###### `category`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.category"></a>

- *Type:* `string`

Categories defined in Amplify CLI like function, api, auth etc.

---

###### `resourceName`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.parameter.resourceName"></a>

- *Type:* `string`

---


#### Properties <a name="Properties"></a>

##### `cfnInclude`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.property.cfnInclude"></a>

```typescript
public readonly cfnInclude: CfnInclude;
```

- *Type:* [`@aws-cdk/cloudformation-include.CfnInclude`](#@aws-cdk/cloudformation-include.CfnInclude)

cfnInclude of the Amplify backend.

---

##### `rootStack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackend.property.rootStack"></a>

```typescript
public readonly rootStack: Stack;
```

- *Type:* [`@aws-cdk/core.Stack`](#@aws-cdk/core.Stack)

The root stack created.

---


## Structs <a name="Structs"></a>

### AmplifyExportedBackendProps <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps"></a>

#### Initializer <a name="[object Object].Initializer"></a>

```typescript
import { AmplifyExportedBackendProps } from '@aws-amplify/cdk-exported-backend'

const amplifyExportedBackendProps: AmplifyExportedBackendProps = { ... }
```

##### `analyticsReporting`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.analyticsReporting"></a>

```typescript
public readonly analyticsReporting: boolean;
```

- *Type:* `boolean`
- *Default:* `analyticsReporting` setting of containing `App`, or value of
'aws:cdk:version-reporting' context key

Include runtime versioning information in this Stack.

---

##### `description`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* `string`
- *Default:* No description.

A description of the stack.

---

##### `env`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.env"></a>

```typescript
public readonly env: Environment;
```

- *Type:* [`@aws-cdk/core.Environment`](#@aws-cdk/core.Environment)
- *Default:* The environment of the containing `Stage` if available,
otherwise create the stack will be environment-agnostic.

The AWS environment (account/region) where this stack will be deployed.

Set the `region`/`account` fields of `env` to either a concrete value to
select the indicated environment (recommended for production stacks), or to
the values of environment variables
`CDK_DEFAULT_REGION`/`CDK_DEFAULT_ACCOUNT` to let the target environment
depend on the AWS credentials/configuration that the CDK CLI is executed
under (recommended for development stacks).

If the `Stack` is instantiated inside a `Stage`, any undefined
`region`/`account` fields from `env` will default to the same field on the
encompassing `Stage`, if configured there.

If either `region` or `account` are not set nor inherited from `Stage`, the
Stack will be considered "*environment-agnostic*"". Environment-agnostic
stacks can be deployed to any environment but may not be able to take
advantage of all features of the CDK. For example, they will not be able to
use environmental context lookups such as `ec2.Vpc.fromLookup` and will not
automatically translate Service Principals to the right format based on the
environment's AWS partition, and other such enhancements.

---

##### `stackName`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.stackName"></a>

```typescript
public readonly stackName: string;
```

- *Type:* `string`
- *Default:* Derived from construct path.

Name to deploy the stack with.

---

##### `synthesizer`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.synthesizer"></a>

```typescript
public readonly synthesizer: IStackSynthesizer;
```

- *Type:* [`@aws-cdk/core.IStackSynthesizer`](#@aws-cdk/core.IStackSynthesizer)
- *Default:* `DefaultStackSynthesizer` if the `@aws-cdk/core:newStyleStackSynthesis` feature flag
is set, `LegacyStackSynthesizer` otherwise.

Synthesis method to use while deploying this stack.

---

##### `tags`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.tags"></a>

```typescript
public readonly tags: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: `string`}
- *Default:* {}

Stack tags that will be applied to all the taggable resources and the stack itself.

---

##### `terminationProtection`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.terminationProtection"></a>

```typescript
public readonly terminationProtection: boolean;
```

- *Type:* `boolean`
- *Default:* false

Whether to enable termination protection for this stack.

---

##### `path`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* `string`

The path to the synthesized folder that contains the artifacts for the Amplify CLI backend ex: ./amplify-synth-out/.

---

##### `stage`<sup>Optional</sup> <a name="@aws-amplify/cdk-exported-backend.AmplifyExportedBackendProps.property.stage"></a>

```typescript
public readonly stage: string;
```

- *Type:* `string`
- *Default:* is 'dev'

The stage that you are going to publish the The amplify backend requires a stage to deploy.

---

### CategoryStackMapping <a name="@aws-amplify/cdk-exported-backend.CategoryStackMapping"></a>

#### Initializer <a name="[object Object].Initializer"></a>

```typescript
import { CategoryStackMapping } from '@aws-amplify/cdk-exported-backend'

const categoryStackMapping: CategoryStackMapping = { ... }
```

##### `category`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.CategoryStackMapping.property.category"></a>

```typescript
public readonly category: string;
```

- *Type:* `string`

---

##### `resourceName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.CategoryStackMapping.property.resourceName"></a>

```typescript
public readonly resourceName: string;
```

- *Type:* `string`

---

##### `service`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.CategoryStackMapping.property.service"></a>

```typescript
public readonly service: string;
```

- *Type:* `string`

---

### ExportManifest <a name="@aws-amplify/cdk-exported-backend.ExportManifest"></a>

#### Initializer <a name="[object Object].Initializer"></a>

```typescript
import { ExportManifest } from '@aws-amplify/cdk-exported-backend'

const exportManifest: ExportManifest = { ... }
```

##### `props`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.ExportManifest.property.props"></a>

```typescript
public readonly props: CfnIncludeProps;
```

- *Type:* [`@aws-cdk/cloudformation-include.CfnIncludeProps`](#@aws-cdk/cloudformation-include.CfnIncludeProps)

---

##### `stackName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.ExportManifest.property.stackName"></a>

```typescript
public readonly stackName: string;
```

- *Type:* `string`

---

### ExportTag <a name="@aws-amplify/cdk-exported-backend.ExportTag"></a>

#### Initializer <a name="[object Object].Initializer"></a>

```typescript
import { ExportTag } from '@aws-amplify/cdk-exported-backend'

const exportTag: ExportTag = { ... }
```

##### `key`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.ExportTag.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* `string`

---

##### `value`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.ExportTag.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* `string`

---

### ProviderCredential <a name="@aws-amplify/cdk-exported-backend.ProviderCredential"></a>

#### Initializer <a name="[object Object].Initializer"></a>

```typescript
import { ProviderCredential } from '@aws-amplify/cdk-exported-backend'

const providerCredential: ProviderCredential = { ... }
```

##### `clientId`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.ProviderCredential.property.clientId"></a>

```typescript
public readonly clientId: string;
```

- *Type:* `string`

---

##### `clientSecret`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.ProviderCredential.property.clientSecret"></a>

```typescript
public readonly clientSecret: string;
```

- *Type:* `string`

---

##### `providerName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.ProviderCredential.property.providerName"></a>

```typescript
public readonly providerName: string;
```

- *Type:* `string`

---

## Classes <a name="Classes"></a>

### APIGraphQLIncludedNestedStack <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack"></a>

#### Initializers <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.Initializer"></a>

```typescript
import { APIGraphQLIncludedNestedStack } from '@aws-amplify/cdk-exported-backend'

new APIGraphQLIncludedNestedStack(includedStack: IncludedNestedStack)
```

##### `includedStack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.parameter.includedStack"></a>

- *Type:* [`@aws-cdk/cloudformation-include.IncludedNestedStack`](#@aws-cdk/cloudformation-include.IncludedNestedStack)

---

#### Methods <a name="Methods"></a>

##### `appSyncAPIKey` <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.appSyncAPIKey"></a>

```typescript
public appSyncAPIKey()
```

##### `getResourceConstruct` <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.getResourceConstruct"></a>

```typescript
public getResourceConstruct(logicalId: string)
```

###### `logicalId`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.parameter.logicalId"></a>

- *Type:* `string`

---

##### `graphQLAPI` <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.graphQLAPI"></a>

```typescript
public graphQLAPI()
```

##### `graphQLSchema` <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.graphQLSchema"></a>

```typescript
public graphQLSchema()
```

##### `modelNestedStack` <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.modelNestedStack"></a>

```typescript
public modelNestedStack(tableName: string)
```

###### `tableName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.parameter.tableName"></a>

- *Type:* `string`

is the model name in your Graph QL API.

---


#### Properties <a name="Properties"></a>

##### `includedTemplate`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.property.includedTemplate"></a>

```typescript
public readonly includedTemplate: CfnInclude;
```

- *Type:* [`@aws-cdk/cloudformation-include.CfnInclude`](#@aws-cdk/cloudformation-include.CfnInclude)

---

##### `stack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIGraphQLIncludedNestedStack.property.stack"></a>

```typescript
public readonly stack: NestedStack;
```

- *Type:* [`@aws-cdk/core.NestedStack`](#@aws-cdk/core.NestedStack)

---


### APIRestIncludedStack <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack"></a>

#### Initializers <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.Initializer"></a>

```typescript
import { APIRestIncludedStack } from '@aws-amplify/cdk-exported-backend'

new APIRestIncludedStack(includedStack: IncludedNestedStack, resourceName: string)
```

##### `includedStack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.parameter.includedStack"></a>

- *Type:* [`@aws-cdk/cloudformation-include.IncludedNestedStack`](#@aws-cdk/cloudformation-include.IncludedNestedStack)

---

##### `resourceName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.parameter.resourceName"></a>

- *Type:* `string`

---

#### Methods <a name="Methods"></a>

##### `apiDeployment` <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.apiDeployment"></a>

```typescript
public apiDeployment()
```

##### `getResourceConstruct` <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.getResourceConstruct"></a>

```typescript
public getResourceConstruct(logicalId: string)
```

###### `logicalId`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.parameter.logicalId"></a>

- *Type:* `string`

---

##### `restAPI` <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.restAPI"></a>

```typescript
public restAPI()
```


#### Properties <a name="Properties"></a>

##### `includedTemplate`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.property.includedTemplate"></a>

```typescript
public readonly includedTemplate: CfnInclude;
```

- *Type:* [`@aws-cdk/cloudformation-include.CfnInclude`](#@aws-cdk/cloudformation-include.CfnInclude)

---

##### `resourceName`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.property.resourceName"></a>

```typescript
public readonly resourceName: string;
```

- *Type:* `string`

---

##### `stack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.APIRestIncludedStack.property.stack"></a>

```typescript
public readonly stack: NestedStack;
```

- *Type:* [`@aws-cdk/core.NestedStack`](#@aws-cdk/core.NestedStack)

---


### AuthIncludedNestedStack <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack"></a>

#### Initializers <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.Initializer"></a>

```typescript
import { AuthIncludedNestedStack } from '@aws-amplify/cdk-exported-backend'

new AuthIncludedNestedStack(includedStack: IncludedNestedStack)
```

##### `includedStack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.parameter.includedStack"></a>

- *Type:* [`@aws-cdk/cloudformation-include.IncludedNestedStack`](#@aws-cdk/cloudformation-include.IncludedNestedStack)

---

#### Methods <a name="Methods"></a>

##### `getResourceConstruct` <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.getResourceConstruct"></a>

```typescript
public getResourceConstruct(logicalId: string)
```

###### `logicalId`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.parameter.logicalId"></a>

- *Type:* `string`

---

##### `hostedUiProviderCredentials` <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.hostedUiProviderCredentials"></a>

```typescript
public hostedUiProviderCredentials(credentials: ProviderCredential[])
```

###### `credentials`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.parameter.credentials"></a>

- *Type:* [`@aws-amplify/cdk-exported-backend.ProviderCredential`](#@aws-amplify/cdk-exported-backend.ProviderCredential)[]

---

##### `identityPool` <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.identityPool"></a>

```typescript
public identityPool()
```

##### `userPool` <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.userPool"></a>

```typescript
public userPool()
```


#### Properties <a name="Properties"></a>

##### `includedTemplate`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.property.includedTemplate"></a>

```typescript
public readonly includedTemplate: CfnInclude;
```

- *Type:* [`@aws-cdk/cloudformation-include.CfnInclude`](#@aws-cdk/cloudformation-include.CfnInclude)

---

##### `stack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.AuthIncludedNestedStack.property.stack"></a>

```typescript
public readonly stack: NestedStack;
```

- *Type:* [`@aws-cdk/core.NestedStack`](#@aws-cdk/core.NestedStack)

---


### LambdaFunctionIncludedNestedStack <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack"></a>

#### Initializers <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack.Initializer"></a>

```typescript
import { LambdaFunctionIncludedNestedStack } from '@aws-amplify/cdk-exported-backend'

new LambdaFunctionIncludedNestedStack(includedStack: IncludedNestedStack)
```

##### `includedStack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack.parameter.includedStack"></a>

- *Type:* [`@aws-cdk/cloudformation-include.IncludedNestedStack`](#@aws-cdk/cloudformation-include.IncludedNestedStack)

---

#### Methods <a name="Methods"></a>

##### `getResourceConstruct` <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack.getResourceConstruct"></a>

```typescript
public getResourceConstruct(logicalId: string)
```

###### `logicalId`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack.parameter.logicalId"></a>

- *Type:* `string`

---

##### `lambdaFunction` <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack.lambdaFunction"></a>

```typescript
public lambdaFunction()
```


#### Properties <a name="Properties"></a>

##### `includedTemplate`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack.property.includedTemplate"></a>

```typescript
public readonly includedTemplate: CfnInclude;
```

- *Type:* [`@aws-cdk/cloudformation-include.CfnInclude`](#@aws-cdk/cloudformation-include.CfnInclude)

---

##### `stack`<sup>Required</sup> <a name="@aws-amplify/cdk-exported-backend.LambdaFunctionIncludedNestedStack.property.stack"></a>

```typescript
public readonly stack: NestedStack;
```

- *Type:* [`@aws-cdk/core.NestedStack`](#@aws-cdk/core.NestedStack)

---



