import { CfnInclude, IncludedNestedStack } from '@aws-cdk/cloudformation-include';
import * as cdk from '@aws-cdk/core';
import { AmplifyExportedBackendProps } from './amplify-exported-backend-props';
import { BaseAmplifyExportedBackend } from './base-exported-backend';
import { APIGraphQLIncludedNestedStack, APIRestIncludedStack, AuthIncludedNestedStack } from './include-nested-stacks';
import { LambdaFunctionIncludedNestedStack } from './include-nested-stacks/lambda-function/lambda-function-nested-stack';
/**
 * * Used to include the backend generated by running `amplify export --out <path>` into the cdk app.
 *
 * @see <amplify-export-docs-path>
 * @stability stable
 */
export declare class AmplifyExportedBackend extends BaseAmplifyExportedBackend {
    /**
     * cfnInclude of the Amplify backend.
     *
     * @stability stable
     */
    cfnInclude: CfnInclude;
    /**
     * The root stack created.
     *
     * @stability stable
     */
    rootStack: cdk.Stack;
    /**
     * @param scope The parent construct of this template.
     * @param id The ID of this construct.
     * @param props Initialization properties.
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: AmplifyExportedBackendProps);
    private applyTags;
    /**
     * Method to get the auth stack.
     *
     * @returns the nested stack of type {IAuthIncludeNestedStack}
     * @stability stable
     * @throws {AmplifyCategoryNotFoundError} if the auth stack doesn't exist
     * @method true
     * @function true
     */
    authNestedStack(): AuthIncludedNestedStack;
    /**
     * Use this to get the api graphql stack from the backend.
     *
     * @returns the nested stack of type {IAPIGraphQLIncludeNestedStack}
     * @stability stable
     * @ true
     * @throws {AmplifyCategoryNotFoundError} if the API graphql stack doesn't exist
     */
    graphqlNestedStacks(): APIGraphQLIncludedNestedStack;
    /**
     * Use this to get all the lambda functions from the backend.
     *
     * @returns
     * @stability stable
     * @throws {AmplifyCategoryNotFoundError} if the no Lambda Function stacks are found
     */
    lambdaFunctionNestedStacks(): LambdaFunctionIncludedNestedStack[];
    /**
     * Use this to get a specific lambda function from the backend.
     *
     * @param functionName the function name to get from the nested stack.
     * @returns
     * @stability stable
     * @throws {AmplifyCategoryNotFoundError} if the lambda function stack doesn't exist
     */
    lambdaFunctionNestedStackByName(functionName: string): LambdaFunctionIncludedNestedStack;
    /**
     * @stability stable
     */
    nestedStackByCategortService(category: string, service: string): IncludedNestedStack[];
    /**
     * Returns the stacks defined in the backend.
     *
     * @param category Categories defined in Amplify CLI like function, api, auth etc.
     * @default is undefined
     * @stability stable
     */
    nestedStacksByCategory(category: string, resourceName?: string): IncludedNestedStack[];
    /**
     * Use this to get rest api stack from the backend.
     *
     * @returns the nested of type Rest API
     * @stability stable
     * @throws {AmplifyCategoryNotFoundError} if the API Rest stack doesn't exist
     */
    apiRestNestedStack(resourceName: string): APIRestIncludedStack;
    private getCategoryNestedStack;
}
